pub trait MemoryAccess {
// Required method
fn get_address(
&mut self,
address: &u32,
num_bytes: usize,
) -> Option<Vec<u8>>;
}Expand description
A trait used for reading memory of the debug target.
Required Methods
Sourcefn get_address(&mut self, address: &u32, num_bytes: usize) -> Option<Vec<u8>>
fn get_address(&mut self, address: &u32, num_bytes: usize) -> Option<Vec<u8>>
Reads a number of bytes from the debugged target.
Description:
address- The address that will be read.num_bytes- The number of bytes that will be read.
This function is used for reading num_bytes bytes in the debugged target system at the
address address.
This is done when evaluating variables that are stored in the memory of the debugged
target.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".